==> texlive-langother-2023.66594-20-any.pkg.tar.xz: var/lib/texmf/arch/installedpkgs/langother.dat.lua <==
	['afrikaans'] = {
		loader = 'loadhyph-af.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-af.pat.txt',
		hyphenation = 'hyph-af.hyp.txt',
	},
	['armenian'] = {
		loader = 'loadhyph-hy.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-hy.pat.txt',
		hyphenation = '',
	},
	['coptic'] = {
		loader = 'loadhyph-cop.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-cop.pat.txt',
		hyphenation = '',
	},
	['esperanto'] = {
		loader = 'loadhyph-eo.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-eo.pat.txt',
		hyphenation = '',
	},
	['ethiopic'] = {
		loader = 'loadhyph-mul-ethi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = { 'amharic', 'geez' },
		patterns = 'hyph-mul-ethi.pat.txt',
		hyphenation = '',
	},
	['georgian'] = {
		loader = 'loadhyph-ka.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-ka.pat.txt',
		hyphenation = '',
	},
	['assamese'] = {
		loader = 'loadhyph-as.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-as.pat.txt',
		hyphenation = '',
	},
	['bengali'] = {
		loader = 'loadhyph-bn.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-bn.pat.txt',
		hyphenation = '',
	},
	['gujarati'] = {
		loader = 'loadhyph-gu.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-gu.pat.txt',
		hyphenation = '',
	},
	['hindi'] = {
		loader = 'loadhyph-hi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-hi.pat.txt',
		hyphenation = '',
	},
	['kannada'] = {
		loader = 'loadhyph-kn.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-kn.pat.txt',
		hyphenation = '',
	},
	['malayalam'] = {
		loader = 'loadhyph-ml.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-ml.pat.txt',
		hyphenation = '',
	},
	['marathi'] = {
		loader = 'loadhyph-mr.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-mr.pat.txt',
		hyphenation = '',
	},
	['oriya'] = {
		loader = 'loadhyph-or.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-or.pat.txt',
		hyphenation = '',
	},
	['pali'] = {
		loader = 'loadhyph-pi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-pi.pat.txt',
		hyphenation = '',
	},
	['panjabi'] = {
		loader = 'loadhyph-pa.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-pa.pat.txt',
		hyphenation = '',
	},
	['tamil'] = {
		loader = 'loadhyph-ta.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-ta.pat.txt',
		hyphenation = '',
	},
	['telugu'] = {
		loader = 'loadhyph-te.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-te.pat.txt',
		hyphenation = '',
	},
	['indonesian'] = {
		loader = 'loadhyph-id.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-id.pat.txt',
		hyphenation = 'hyph-id.hyp.txt',
	},
	['interlingua'] = {
		loader = 'loadhyph-ia.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-ia.pat.txt',
		hyphenation = 'hyph-ia.hyp.txt',
	},
	['sanskrit'] = {
		loader = 'loadhyph-sa.tex',
		lefthyphenmin = 1,
		righthyphenmin = 3,
		synonyms = {  },
		patterns = 'hyph-sa.pat.txt',
		hyphenation = '',
	},
	['thai'] = {
		loader = 'loadhyph-th.tex',
		lefthyphenmin = 2,
		righthyphenmin = 3,
		synonyms = {  },
		patterns = 'hyph-th.pat.txt',
		hyphenation = '',
	},
	['turkmen'] = {
		loader = 'loadhyph-tk.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-tk.pat.txt',
		hyphenation = '',
	},

==> texlive-langother-2025.2-1-any.pkg.tar.xz: var/lib/texmf/arch/installedpkgs/langother.dat.lua <==
	['afrikaans'] = {
		loader = 'loadhyph-af.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-af.pat.txt',
		hyphenation = 'hyph-af.hyp.txt',
	},
	['armenian'] = {
		loader = 'loadhyph-hy.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-hy.pat.txt',
		hyphenation = '',
	},
	['coptic'] = {
		loader = 'loadhyph-cop.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-cop.pat.txt',
		hyphenation = '',
	},
	['esperanto'] = {
		loader = 'loadhyph-eo.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-eo.pat.txt',
		hyphenation = '',
	},
	['ethiopic'] = {
		loader = 'loadhyph-mul-ethi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = { 'amharic', 'geez' },
		patterns = 'hyph-mul-ethi.pat.txt',
		hyphenation = '',
	},
	['georgian'] = {
		loader = 'loadhyph-ka.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-ka.pat.txt',
		hyphenation = '',
	},
	['hebrew'] = {
		loader = 'hyph-he.tex',
		lefthyphenmin = 0,
		righthyphenmin = 0,
		synonyms = {  },
	},
	['assamese'] = {
		loader = 'loadhyph-as.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-as.pat.txt',
		hyphenation = '',
	},
	['bengali'] = {
		loader = 'loadhyph-bn.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-bn.pat.txt',
		hyphenation = '',
	},
	['gujarati'] = {
		loader = 'loadhyph-gu.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-gu.pat.txt',
		hyphenation = '',
	},
	['hindi'] = {
		loader = 'loadhyph-hi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-hi.pat.txt',
		hyphenation = '',
	},
	['kannada'] = {
		loader = 'loadhyph-kn.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-kn.pat.txt',
		hyphenation = '',
	},
	['malayalam'] = {
		loader = 'loadhyph-ml.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-ml.pat.txt',
		hyphenation = '',
	},
	['marathi'] = {
		loader = 'loadhyph-mr.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-mr.pat.txt',
		hyphenation = '',
	},
	['oriya'] = {
		loader = 'loadhyph-or.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-or.pat.txt',
		hyphenation = '',
	},
	['pali'] = {
		loader = 'loadhyph-pi.tex',
		lefthyphenmin = 1,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-pi.pat.txt',
		hyphenation = '',
	},
	['panjabi'] = {
		loader = 'loadhyph-pa.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-pa.pat.txt',
		hyphenation = '',
	},
	['tamil'] = {
		loader = 'loadhyph-ta.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-ta.pat.txt',
		hyphenation = '',
	},
	['telugu'] = {
		loader = 'loadhyph-te.tex',
		lefthyphenmin = 1,
		righthyphenmin = 1,
		synonyms = {  },
		patterns = 'hyph-te.pat.txt',
		hyphenation = '',
	},
	['indonesian'] = {
		loader = 'loadhyph-id.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-id.pat.txt',
		hyphenation = 'hyph-id.hyp.txt',
	},
	['interlingua'] = {
		loader = 'loadhyph-ia.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-ia.pat.txt',
		hyphenation = 'hyph-ia.hyp.txt',
	},
	['sanskrit'] = {
		loader = 'loadhyph-sa.tex',
		lefthyphenmin = 1,
		righthyphenmin = 3,
		synonyms = {  },
		patterns = 'hyph-sa.pat.txt',
		hyphenation = '',
	},
	['thai'] = {
		loader = 'loadhyph-th.tex',
		lefthyphenmin = 2,
		righthyphenmin = 3,
		synonyms = {  },
		patterns = 'hyph-th.pat.txt',
		hyphenation = '',
	},
	['turkmen'] = {
		loader = 'loadhyph-tk.tex',
		lefthyphenmin = 2,
		righthyphenmin = 2,
		synonyms = {  },
		patterns = 'hyph-tk.pat.txt',
		hyphenation = '',
	},
	['vietnamese'] = {
		loader = 'hyph-vi.tex',
		lefthyphenmin = 0,
		righthyphenmin = 0,
		synonyms = {  },
	},
